<?php
require FODE_DIR . 'lib/theme-config/config-tgm/_class-tgm-plugin-activation.php'; 

add_action( 'tgmpa_register', 'fode_register_required_plugins' );

/**
 * Register the required plugins for this theme.
 *
 * In this example, we register five plugins:
 * - one included with the TGMPA library
 * - two from an external source, one from an arbitrary source, one from a GitHub repository
 * - two from the .org repo, where one demonstrates the use of the `is_callable` argument
 *
 * The variables passed to the `tgmpa()` function should be:
 * - an array of plugin arrays;
 * - optionally a configuration array.
 * If you are not changing anything in the configuration array, you can remove the array and remove the
 * variable from the function call: `tgmpa( $plugins );`.
 * In that case, the TGMPA default settings will be used.
 *
 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
 */
function fode_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		//This is an example of how to include a plugin bundled with a theme. 
		array(
			'name'               => esc_html__('Theme Core','fode'), // The plugin name.
			'slug'               => 'theme-core', // The plugin slug (typically the folder name).
			'source'             => FODE_DIR . '/lib/plugins/theme-core.zip', // The plugin source.
			'required'           => true,  
		),  
		array(
			'name'               => esc_html__('WPBakery Visual Composer','fode'), // The plugin name.
			'slug'               => 'js_composer', // The plugin slug (typically the folder name).
			'source'             => FODE_DIR . '/lib/plugins/js_composer.zip', // The plugin source.
			'required'           => true,  
		), 
		array(
			'name'      => esc_html__('Contact Form 7','fode'),
			'slug'      => 'contact-form-7',
			'required'  => false,
		), 
		array(
			'name'      => esc_html__('CMB2','fode'),
			'slug'      => 'cmb2',
			'required'  => true,
		), 
		array(
			'name'      => esc_html__('One Click Demo Import','fode'),
			'slug'      => 'one-click-demo-import',
			'required'  => false,
		), 
		array(
			'name'      => esc_html__('Redux Framework','fode'),
			'slug'      => 'redux-framework',
			'required'  => true,
		), 
		array(
			'name'      => esc_html__('Mailchimp for WP','fode'),
			'slug'      => 'mailchimp-for-wp',
			'required'  => false,
		)
	); 

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'fode',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}
