<?php 
/**
 * Theme Core Functions 
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**===============================================================================
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 ===============================================================================*/

if ( ! function_exists( 'fode_setup' ) ) :

function fode_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Ja, use a find and replace
	 * to change 'fode' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'fode', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Woocommerce Support. 
	 */

	add_theme_support( 'woocommerce' );
	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'fode-gallery', 1200, 736, true ); 
	add_image_size( 'fode-blog', 358, 251, true ); 

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'mainmenu' => esc_html__( 'Main Menu', 'fode' ), 
		'mobilermenu' => esc_html__( 'Mobile Menu', 'fode' ), 
		'footermenu' => esc_html__( 'Footer Menu', 'fode' ), 
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array( 
		'video',
		'quote', 
		'gallery',
		'audio',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'fode_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style( array( 'assets/css/editor-style.css', fode_fonts_url() ) );
}
endif;
add_action( 'after_setup_theme', 'fode_setup' );



/**===============================================================================
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 ===============================================================================*/
function fode_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'fode_content_width', 640 );
}
add_action( 'after_setup_theme', 'fode_content_width', 0 );


/**===============================================================================
 * Register Functions
 =================================================================================*/
if ( file_exists( FODE_DIR . 'lib/theme-core-functions/_register.php')) { 
	load_template( FODE_DIR . 'lib/theme-core-functions/_register.php'); 
}

/**===============================================================================
 * Enqueue Theme Assets (Scripts & Styles)
 =================================================================================*/
if ( file_exists( FODE_DIR . 'lib/theme-core-functions/_enqueue-assets.php')) { 
	load_template( FODE_DIR . 'lib/theme-core-functions/_enqueue-assets.php');  
}


/**===============================================================================
 * Helper Functions
 =================================================================================*/
if ( file_exists( FODE_DIR . 'lib/theme-core-functions/_helpers.php')) {  
	load_template( FODE_DIR . 'lib/theme-core-functions/_helpers.php');  
}

